CILogon
-------

CILogon is a federated identity provider for hundreds of universities and research institutions around the world.

App registration (get your key and secret here)
    https://cilogon.org/oauth2/register

CILogon OIDC/OAuth2 Documentation
    https://www.cilogon.org/oidc
